﻿/// @file wavtool.h
///
/// wavtool.h
///
#ifndef _WAVTOOL_H_
#define _WAVTOOL_H_

#include "common.h"
#include <wx/wx.h>
#include <wx/dnd.h>
#include "config.h"

class WavtoolApp;
class WavtoolFrame;
class WavtoolPanel;
class WavtoolFileDialog;
class WavtoolFileDropTarget;

class PARSEWAV;
class ConfigBox;

/// @brief Window
class WavtoolApp: public wxApp
{
private:
	wxString app_path;
	wxString ini_path;
	wxString res_path;
	wxLocale mLocale;

	void SetAppPath();
public:
	WavtoolApp() : mLocale(wxLANGUAGE_DEFAULT) {}
	bool OnInit();
	int  OnExit();
	const wxString &GetAppPath();
	const wxString &GetIniPath();
	const wxString &GetResPath();
};

DECLARE_APP(WavtoolApp)

/// @brief Frame
class WavtoolFrame: public wxFrame
{
private:
	// gui
	wxMenu *menuFile;
	wxMenu *menuRecentFiles;
	wxMenu *menuSets;
	wxMenu *menuHelp;
	WavtoolPanel *panel;

	PARSEWAV *wav;

	ConfigBox *cfgbox;

	wxString text_buffer;

public:

    WavtoolFrame(const wxString& title, const wxSize& size);
	~WavtoolFrame();

	// event procedures
	void OnQuit(wxCommandEvent& event);
	void OnAbout(wxCommandEvent& event);

	void OnOpenFile(wxCommandEvent& event);
	void OnOpenRecentFile(wxCommandEvent& event);
	void OnCloseFile(wxCommandEvent& event);

	void OnExportFile(wxCommandEvent& event);

	void OnAnalyzeWave(wxCommandEvent& event);
	void OnAnalyzeFiles(wxCommandEvent& event);

	void OnSetsRftype(wxCommandEvent& event);
	void OnSetsMachine(wxCommandEvent& event);

	void OnSetsBaudRate(wxCommandEvent& event);

	void OnSetsCorrectType(wxCommandEvent& event);

	void OnConfigure(wxCommandEvent& event);

	void OnMenuOpen(wxMenuEvent& event);

//	void OnDropFiles(wxDropFilesEvent& event);

	// functions
	void OpenDataFile(wxString &path);
	void CloseDataFile();
	void ExportFile(int id);
	void OpenDroppedFile(wxString &path);
	void UpdateMenu(wxMenu *menu);
	void UpdateFileMenu();
	void UpdateSettingMenu();
	void UpdateMenuRecentFiles();

	// properties
	WavtoolPanel *GetWavtoolPanel() { return panel; }

	enum
	{
		// menu id
		IDM_EXIT = 1,
		IDM_ABOUT,
		IDM_OPEN_FILE,
		IDM_CLOSE_FILE,
		IDM_EXPORT,
		IDM_EXPORT_REAL,
		IDM_EXPORT_L3,
		IDM_EXPORT_T9X,
		IDM_EXPORT_L3B,
		IDM_EXPORT_L3C,
		IDM_EXPORT_WAV,
		IDM_ANALYZE_WAV,
		IDM_ANALYZE_FILES,
		IDM_SETS_RFTYPE,
		IDM_SETS_MACHINE,
		IDM_SETS_BAUD,
		IDM_SETS_BAUD_AUTO,
		IDM_SETS_BAUD_600,
		IDM_SETS_BAUD_1200,
		IDM_SETS_BAUD_2400,
		IDM_SETS_BAUD_300,
		IDM_SETS_CORRECT,
		IDM_SETS_CORRECT_NONE,
		IDM_SETS_CORRECT_COS,
		IDM_SETS_CORRECT_SIN,
		IDM_SETS_CONFIGURE,

		IDM_RECENT_FILE_0,
		IDM_RECENT_FILE_1,
		IDM_RECENT_FILE_2,
		IDM_RECENT_FILE_3,
		IDM_RECENT_FILE_4,
		IDM_RECENT_FILE_5,
		IDM_RECENT_FILE_6,
		IDM_RECENT_FILE_7,
		IDM_RECENT_FILE_8,
		IDM_RECENT_FILE_9,

		IDD_CONFIGBOX,
	};

	DECLARE_EVENT_TABLE()
};

/// @brief Panel
class WavtoolPanel: public wxPanel
{
private:
	wxTextCtrl *textName;
	wxTextCtrl *textInfo;

public:
	WavtoolPanel(WavtoolFrame *parent);

	// event procedures
	void OnSize(wxSizeEvent& event);

	// properties
	wxTextCtrl *GetTextName() { return textName; }
	wxTextCtrl *GetTextInfo() { return textInfo; }


	enum {
		IDC_TEXT_NAME = 1,
		IDC_TEXT_INFO,
	};

	DECLARE_EVENT_TABLE()
};

/// @brief for file dialog
class WavtoolFileDialog: public wxFileDialog
{
public:
	WavtoolFileDialog(const wxString& message, const wxString& defaultDir = wxEmptyString, const wxString& defaultFile = wxEmptyString, const wxString& wildcard = wxFileSelectorDefaultWildcardStr, long style = wxFD_DEFAULT_STYLE);

};

/// @brief for drop
class WavtoolFileDropTarget : public wxFileDropTarget
{
    WavtoolFrame *frame;
public:
    WavtoolFileDropTarget(WavtoolFrame *parent);
    bool OnDropFiles(wxCoord x, wxCoord y ,const wxArrayString &filenames);
};

/// @brief About dialog
class WavtoolAbout : public wxDialog
{
public:
	WavtoolAbout(wxWindow* parent, wxWindowID id);
};

#endif /* _WAVTOOL_H_ */

